==> karma-event-driver-ext-0.0.11.tgz: package/karma.conf.js <==
var path = require('path')
var webpack = require('webpack')
var coverage = String(process.env.COVERAGE) !== 'false'

module.exports = function(config) {
    config.set({
        // hostname: '100.80.21.114',

        // base path that will be used to resolve all patterns (eg. files, exclude)
        //  basePath: '',


        // frameworks to use
        // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
        frameworks: ['jasmine'],


        // list of files / patterns to load in the browser
        files: ['./test/*.spec.js'],


        // list of files to exclude
        exclude: [],


        // preprocess matching files before serving them to the browser
        // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor

        // test results reporter to use
        // possible values: 'dots', 'progress'
        // available reporters: https://npmjs.org/browse/keyword/karma-reporter
        reporters: ['spec', 'coverage'],
        preprocessors: {
            './test/*.spec.js': ['webpack'],
            './src/*.js': ['webpack', 'coverage']
        },
        mochaReporter: { showDiff: true },
        browserLogOptions: {
            terminal: true
        },
        browserConsoleLogOptions: {
            terminal: true
        },
        coverageReporter: {
            type: 'html',
            dir: 'coverage/'
        },
        webpack: {

            module: {
                /* Transpile source and test files */
                preLoaders: [{
                    test: /\.jsx?$/,
                    exclude: path.resolve(__dirname, 'node_modules'),
                    loader: 'babel-loader',
                    query: {
                        plugins: ['istanbul'],
                        babelrc: true
                    }
                }],
                /* Only Instrument our source files for coverage */
                loaders: []
            },
            resolve: {

                alias: {},
                modulesDirectories: [__dirname, 'node_modules']
            },
            plugins: [
                new webpack.DefinePlugin({ //添加全局变量
                    coverage: coverage,
                    NODE_ENV: JSON.stringify(process.env.NODE_ENV || ''),
                })
            ]
        },
        webpackMiddleware: {
            noInfo: true //去掉编译文件的LOG
        },
        //hostname: '127.0.0.1',
        // web server port
        port: 9876,


        // enable / disable colors in the output (reporters and logs)
        colors: true,


        // level of logging
        // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
        //    logLevel: config.LOG_INFO,


        // enable / disable watching file and executing tests whenever any file changes
        autoWatch: true,


        // start these browsers
        // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
        // browsers: ['Chrome', 'Firefox', 'PhantomJS'],
        customLaunchers: {
            'Safari': {
                base: 'WebDriverio',
                browserName: 'Safari',
                name: 'Karma',
                config: {
                    port: 4723,
                    logLevel: 'verbose',
                    desiredCapabilities: {
                        'appium-version': '1.6',
                        platformName: 'iOS',
                        platformVersion: '10.3',
                        deviceName: 'iPhone 5',
                        browserName: 'Safari',
                        app: undefined
                    }
                }
            },
            'Chrome2': {
                base: 'WebDriverio',
                browserName: 'chrome',
                name: 'Karma',
                config: {
                    port: 4723,
                    logLevel: 'verbose',
                    desiredCapabilities: {
                        'appium-version': '1.6',
                        platformName: 'Android',
                        platformVersion: '5.1',
                        deviceName: '91QECP856KTT',
                        browserName: 'chrome',
                        app: undefined
                    }
                }
            },
            'Chrome': {
                base: 'WebDriverio',
                browserName: 'chrome',
                name: 'Karma',
                config: {
                    host: '127.0.0.1',
                    port: 4445,
                    logLevel: 'verbose',
                    user: 'skipper_yqj',
                    key: '272146a5-46cb-441e-9b97-4237102dd4d5',
                }
            }
        },
        browsers: ['Safari'],

        // Continuous Integration mode
        // if true, Karma captures browsers, runs the tests and exits
        singleRun: true,

        // Concurrency level
        // how many browser should be started simultaneous
        concurrency: Infinity
    })
}

==> karma-event-driver-ext-0.0.12.tgz: package/karma.conf.js <==
var path = require('path')
var webpack = require('webpack')
var coverage = String(process.env.COVERAGE) !== 'false'

module.exports = function(config) {
    config.set({
        // hostname: '100.80.21.114',

        // base path that will be used to resolve all patterns (eg. files, exclude)
        //  basePath: '',


        // frameworks to use
        // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
        frameworks: ['jasmine'],


        // list of files / patterns to load in the browser
        files: ['./test/*.spec.js'],


        // list of files to exclude
        exclude: [],


        // preprocess matching files before serving them to the browser
        // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor

        // test results reporter to use
        // possible values: 'dots', 'progress'
        // available reporters: https://npmjs.org/browse/keyword/karma-reporter
        reporters: ['spec', 'coverage'],
        preprocessors: {
            './test/*.spec.js': ['webpack'],
            './src/*.js': ['webpack', 'coverage']
        },
        mochaReporter: { showDiff: true },
        browserLogOptions: {
            terminal: true
        },
        browserConsoleLogOptions: {
            terminal: true
        },
        coverageReporter: {
            type: 'html',
            dir: 'coverage/'
        },
        webpack: {

            module: {
                /* Transpile source and test files */
                preLoaders: [{
                    test: /\.jsx?$/,
                    exclude: path.resolve(__dirname, 'node_modules'),
                    loader: 'babel-loader',
                    query: {
                        plugins: ['istanbul'],
                        babelrc: true
                    }
                }],
                /* Only Instrument our source files for coverage */
                loaders: []
            },
            resolve: {

                alias: {},
                modulesDirectories: [__dirname, 'node_modules']
            },
            plugins: [
                new webpack.DefinePlugin({ //添加全局变量
                    coverage: coverage,
                    NODE_ENV: JSON.stringify(process.env.NODE_ENV || ''),
                })
            ]
        },
        webpackMiddleware: {
            noInfo: true //去掉编译文件的LOG
        },
        //hostname: '127.0.0.1',
        // web server port
        port: 9876,


        // enable / disable colors in the output (reporters and logs)
        colors: true,


        // level of logging
        // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
        //    logLevel: config.LOG_INFO,


        // enable / disable watching file and executing tests whenever any file changes
        autoWatch: true,


        // start these browsers
        // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
        // browsers: ['Chrome', 'Firefox', 'PhantomJS'],
        customLaunchers: {
            'Safari': {
                base: 'WebDriverio',
                browserName: 'Safari',
                name: 'Karma',
                config: {
                    port: 4723,
                    logLevel: 'verbose',
                    desiredCapabilities: {
                        'appium-version': '1.6',
                        platformName: 'iOS',
                        platformVersion: '10.3',
                        deviceName: 'iPhone 5',
                        browserName: 'Safari',
                        app: undefined
                    }
                }
            },
            'Chrome2': {
                base: 'WebDriverio',
                browserName: 'chrome',
                name: 'Karma',
                config: {
                    port: 4723,
                    logLevel: 'verbose',
                    desiredCapabilities: {
                        'appium-version': '1.6',
                        platformName: 'Android',
                        platformVersion: '5.1',
                        deviceName: '91QECP856KTT',
                        browserName: 'chrome',
                        app: undefined
                    }
                }
            },
            'Chrome': {
                base: 'WebDriverio',
                browserName: 'chrome',
                name: 'Karma',
                // config: {
                //     host: '127.0.0.1',
                //     port: 4445,
                //     logLevel: 'verbose',
                //     user: 'skipper_yqj',
                //     key: '272146a5-46cb-441e-9b97-4237102dd4d5',
                // }
            }
        },
        browsers: ['Chrome'],

        // Continuous Integration mode
        // if true, Karma captures browsers, runs the tests and exits
        singleRun: true,

        // Concurrency level
        // how many browser should be started simultaneous
        concurrency: Infinity
    })
}
